@@ -1,9 +1,11 @@
 HOUSE = 'HOUSE'
 SENATE = 'SENATE'
+SBOE = 'SBOE'
 
 TYPE_CHOICES = (
     (HOUSE, 'House'),
     (SENATE, 'Senate'),
+    (SBOE, 'State Board of Education'),
 )
 
 REMEDIAL = 'REMEDIAL'
